agentle.agents.a2a.tasks.task\_artifact\_update\_event
======================================================

.. automodule:: agentle.agents.a2a.tasks.task_artifact_update_event

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      Artifact
      BaseModel
      TaskArtifactUpdateEvent
   